<?php

namespace Drupal\synimport\Service;

use Symfony\Component\Process\Process;

/**
 * Log messages.
 */
class Logger {
  /**
   * Console message color.
   *
   * @var array
   */
  protected $colors = [];

  /**
   * Set up shell colors.
   */
  public function __construct() {
    $this->colors['red'] = '0;31';
    $this->colors['green'] = '1;32';
    $this->colors['yellow'] = '1;33';
    $this->colors['blue'] = '1;34';
  }

  /**
   * Usual message.
   */
  public function message(string $msg) {
    $this->log($msg);
    $this->send($msg);
  }

  /**
   * Redd error message.
   */
  public function error(string $msg) {
    $prefix = $this->setColor('[ERROR]', 'red');
    $this->log("$prefix $msg");
    $this->send("[WARNING] $msg");
  }

  /**
   * Yellow warning message.
   */
  public function warning(string $msg) {
    $prefix = $this->setColor('[WARNING]', 'yellow');
    $this->log("$prefix $msg");
    $this->send("[WARNING] $msg");
  }

  /**
   * Blue notice message.
   */
  public function notice(string $msg) {
    $prefix = $this->setColor('[NOTICE]', 'blue');
    $this->log("$prefix $msg");
    $this->send("[NOTICE] $msg");
  }

  /**
   * Green success message.
   */
  public function success(string $msg) {
    $prefix = $this->setColor('[SUCCESS]', 'green');
    $this->log("$prefix $msg");
    $this->send("[SUCCESS] $msg");
  }

  /**
   * Returns colored string.
   */
  public function setColor($string, $color = NULL) {
    $colored_string = "";
    if (isset($this->colors[$color])) {
      $colored_string .= "\033[" . $this->colors[$color] . "m";
    }
    $colored_string .= $string . "\033[0m";
    return $colored_string;
  }

  /**
   * Send to docker.
   */
  public function send(string $msg) {
    $timeout = 60000;
    $cmd = "cd ../console/ && ./console.php tpl:echo '$msg'";
    $process = new Process($cmd);
    $process->setTimeout($timeout);
    $process->start();
    $process->wait();
    return [
      'success' => $process->isSuccessful(),
      'output' => $process->getOutput(),
      'error' => $process->getErrorOutput(),
    ];
  }

  /**
   * Log to console.
   */
  public function log(string $msg) {
    print_r($msg);
    print_r("\n");
  }

}
